Max Size
You did not enter a valid integer.
You did not enter a non-negative number.
You must supply a maximum size.
You must supply an integer.
Min Size
You did not enter a valid integer.
You did not enter a non-negative number.
You must supply a minimum size.
You must supply an integer.
Select Resource Type by: existing items uploading a template file
You did not specify Resource Type.
Resource Type {$ resource_type $}
Resource Type choose a file
Resource Type Content
Resource Properties
Property Value
Cooldown
You did not enter a valid integer.
You did not enter a non-negative number.
You must supply an integer.
Desired Capacity
You did not enter a valid integer.
You did not enter a non-negative number.
You must supply an integer.
Rolling Updates Min In Service
You did not enter a valid integer.
You did not enter a non-negative number.
You must supply an integer.
Pause Time
You did not enter a valid number.
You did not enter a non-negative number.
Max Batch Size
You did not enter a valid integer.
You did not enter a positive number.
You must supply an integer.